@@ -47,7 +47,7 @@ def insertkeywordandentity(words, location, config, ge):
         words[diff] = last
         return words
 
-def insert_entities(config):
+def insert_entities(config, entities_changed = []):
     sp = spacy.load('en_core_web_sm')
     # with open('/entityfaker/config.json',encoding="utf8") as f:
     #     config = json.load(f)
@@ -86,11 +86,20 @@ def insert_entities(config):
         filenamekeywords = []
         with open(file_dest + "/dataset" + str(dist+1)+"/"+f, 'w',encoding="utf-8") as fl:
             enties_to_insert = random.choices(config["entities"], k=entity_count)
+            count = 0
             for t in enties_to_insert:
-                keyword = random.choice([KeywordsType.Specific, KeywordsType.Generic, KeywordsType.Empty])
+                if(config["entity_keywords"][count] == "specific"):
+                    keyword = KeywordsType.Specific
+                elif (config["entity_keywords"][count] == "generic"):
+                    keyword = KeywordsType.Generic
+                elif (config["entity_keywords"][count] == "empty"):
+                    keyword = KeywordsType.Empty
+                elif (config["entity_keywords"][count] == "conflict"):
+                    keyword = KeywordsType.Conflict
+                # keyword = random.choice([KeywordsType.Specific, KeywordsType.Generic, KeywordsType.Empty])
                 # keyword = random.choice([KeywordsType.Specific,KeywordsType.Generic,KeywordsType.Empty])
                 instances = config["entities"].index(t)
-                generated_entities = generate_entites(t, keyword, config["entities_instances"][instances])
+                generated_entities = generate_entites(t, keyword, config["entities_instances"][instances], entities_changed)
                 for ge in generated_entities:
                     location = random.choice([InsertLocation.KeyValue,InsertLocation.SameLineBeforeEntity,InsertLocation.SameLineAfterEntity,InsertLocation.DiffLineBeforeEntity,InsertLocation.DiffLineAfterEntity,InsertLocation.InFileName])
                     if(location == InsertLocation.InFileName):
@@ -121,11 +130,12 @@ def insert_entities(config):
                         "end": end,
                         "labeltype": "true positive"
                     }) 
+                count += 1
             if(len(config["confilict_entities"])>0):
                 conflict_enties_to_insert = random.choices(config["confilict_entities"], k=entity_count)
                 for c in conflict_enties_to_insert:
                     conflict_instances = config["confilict_entities"].index(c)
-                    generated_conflict_entities = generate_entites(c, KeywordsType.Conflict,config["confilict_entities_instances"][conflict_instances])
+                    generated_conflict_entities = generate_entites(c, KeywordsType.Conflict,config["confilict_entities_instances"][conflict_instances],entities_changed)
                     for ge in generated_conflict_entities:
                         location = random.choice([InsertLocation.KeyValue,InsertLocation.SameLineBeforeEntity,InsertLocation.SameLineAfterEntity,InsertLocation.DiffLineBeforeEntity,InsertLocation.DiffLineAfterEntity,InsertLocation.InFileName])
                         # if(location == InsertLocation.InFileName):
